==> eightyone_1.10.20100513-2.tar.gz: eightyone-1.10.20100513/src/GameArea.h <==
#ifndef GAMEAREA_H
#define GAMEAREA_H

/*
  EightyOne - A simple Sudoku solving game
  Copyright (C) 2006  Tim Teulings

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include <Lum/Object.h>

#include <Lum/Model/Action.h>
#include <Lum/Model/Boolean.h>

#include "Sudoku.h"

class GameArea : public Lum::Object
{
private:
  Lum::OS::FontRef       minFont;
  Lum::OS::FontRef       minMarkFont;
  Lum::OS::FontRef       font;
  Lum::OS::FontRef       markFont;
  Lum::OS::ColorRef      presetColor;
  Lum::OS::ColorRef      focusBackgroundColor;
  Lum::OS::ColorRef      errorColor;
  Lum::OS::ColorRef      correctColor;
  Lum::OS::ColorRef      hintColor;
  size_t                 boxSize;
  size_t                 size;
  Sudoku                 game;
  Sudoku                 riddle;
  Sudoku                 solution;
  size_t                 marks[Sudoku::size];
  size_t                 focusedCell;

  Lum::Model::ActionRef  focusChangedAction;
  Lum::Model::BooleanRef hintMode;
  Lum::Model::BooleanRef finished;

private:
  int GetCellOffset( size_t index) const;
  void SetFinished(bool finished);

public:
  GameArea();

  void SetModel(const Sudoku &riddle, const Sudoku &solution);

  void SetGame(const Game& game);

  void GetGame(Game& game) const;
  void GetGame(Sudoku& game) const;
  void GetRiddle(Sudoku& riddle) const;
  void GetSolution(Sudoku& solution) const;

  void CalcSize();
  void Layout();

  Lum::OS::Font* FindFont(Lum::OS::Font* minFont,
                          size_t size);

  void Draw(int x, int y, size_t w, size_t h);

  bool HandlesFocus() const;
  bool HandleMouseEvent(const Lum::OS::MouseEvent& event);
  bool HandleKeyEvent(const Lum::OS::KeyEvent& event);

  Lum::Model::Action* GetFocusChangedAction() const;
  Lum::Model::Boolean* GetFinishedModel() const;
  Lum::Model::Boolean* GetHintMode() const;

  bool IsFocusedCellEditable() const;
  bool IsCellInMarkModus() const;
  size_t GetFocusedCellValue() const;
  size_t GetFocusedCellMarks() const;
  void SetFocusedCellValue(size_t value);
  void SetFocusedCellMarks(size_t value);
  void MarkEmpty();

  void Solve();

  void Resync(Lum::Base::Model *model, const Lum::Base::ResyncMsg& msg);
};

#endif

==> eightyone_1.10.20101005-1.tar.gz: eightyone-1.10.20101005/src/GameArea.h <==
#ifndef GAMEAREA_H
#define GAMEAREA_H

/*
  EightyOne - A simple Sudoku solving game
  Copyright (C) 2006  Tim Teulings

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include <Lum/Object.h>

#include <Lum/Model/Action.h>
#include <Lum/Model/Boolean.h>

#include "Sudoku.h"

class GameArea : public Lum::Object
{
private:
  Lum::OS::FontRef       minFont;
  Lum::OS::FontRef       minMarkFont;
  Lum::OS::FontRef       font;
  Lum::OS::FontRef       markFont;
  Lum::OS::ColorRef      presetColor;
  Lum::OS::ColorRef      focusBackgroundColor;
  Lum::OS::ColorRef      errorColor;
  Lum::OS::ColorRef      correctColor;
  Lum::OS::ColorRef      hintColor;
  size_t                 boxSize;
  size_t                 size;
  Sudoku                 game;
  Sudoku                 riddle;
  Sudoku                 solution;
  size_t                 marks[Sudoku::size];
  size_t                 focusedCell;

  Lum::Model::ActionRef  focusChangedAction;
  Lum::Model::BooleanRef hintMode;
  Lum::Model::BooleanRef finished;

private:
  int GetCellOffset( size_t index) const;
  void SetFinished(bool finished);

public:
  GameArea();

  bool HandlesClickFocus() const;
  bool HandlesKeyFocus() const;

  void SetModel(const Sudoku &riddle, const Sudoku &solution);

  void SetGame(const Game& game);

  void GetGame(Game& game) const;
  void GetGame(Sudoku& game) const;
  void GetRiddle(Sudoku& riddle) const;
  void GetSolution(Sudoku& solution) const;

  void CalcSize();
  void Layout();

  Lum::OS::Font* FindFont(Lum::OS::Font* minFont,
                          size_t size);

  void Draw(Lum::OS::DrawInfo* draw,
            int x, int y, size_t w, size_t h);

  bool HandleMouseEvent(const Lum::OS::MouseEvent& event);
  bool HandleKeyEvent(const Lum::OS::KeyEvent& event);

  Lum::Model::Action* GetFocusChangedAction() const;
  Lum::Model::Boolean* GetFinishedModel() const;
  Lum::Model::Boolean* GetHintMode() const;

  bool IsFocusedCellEditable() const;
  bool IsCellInMarkModus() const;
  size_t GetFocusedCellValue() const;
  size_t GetFocusedCellMarks() const;
  void SetFocusedCellValue(size_t value);
  void SetFocusedCellMarks(size_t value);
  void MarkEmpty();

  void Solve();

  void Resync(Lum::Base::Model *model, const Lum::Base::ResyncMsg& msg);
};

#endif
